@@ -35,15 +35,12 @@ func (c *Config) newArchiveCmd() *cobra.Command {
 		),
 	}
 
-	flags := archiveCmd.Flags()
-	flags.VarP(c.archive.filter.Exclude, "exclude", "x", "Exclude entry types")
-	flags.VarP(&c.archive.format, "format", "f", "Set archive format")
-	flags.BoolVarP(&c.archive.gzip, "gzip", "z", c.archive.gzip, "Compress output with gzip")
-	flags.VarP(c.archive.filter.Exclude, "include", "i", "Include entry types")
-	flags.BoolVar(&c.archive.init, "init", c.archive.init, "Recreate config file from template")
-	flags.BoolVarP(&c.archive.recursive, "recursive", "r", c.archive.recursive, "Recurse into subdirectories")
-
-	registerExcludeIncludeFlagCompletionFuncs(archiveCmd)
+	archiveCmd.Flags().VarP(c.archive.filter.Exclude, "exclude", "x", "Exclude entry types")
+	archiveCmd.Flags().VarP(&c.archive.format, "format", "f", "Set archive format")
+	archiveCmd.Flags().BoolVarP(&c.archive.gzip, "gzip", "z", c.archive.gzip, "Compress output with gzip")
+	archiveCmd.Flags().VarP(c.archive.filter.Exclude, "include", "i", "Include entry types")
+	archiveCmd.Flags().BoolVar(&c.archive.init, "init", c.archive.init, "Recreate config file from template")
+	archiveCmd.Flags().BoolVarP(&c.archive.recursive, "recursive", "r", c.archive.recursive, "Recurse into subdirectories")
 
 	return archiveCmd
 }
