@@ -2,6 +2,10 @@ package cmd
 
 import "github.com/spf13/cobra"
 
+type secretCmdConfig struct {
+	keyring secretKeyringCmdConfig
+}
+
 func (c *Config) newSecretCmd() *cobra.Command {
 	secretCmd := &cobra.Command{
 		Use:     "secret",
@@ -11,7 +15,9 @@ func (c *Config) newSecretCmd() *cobra.Command {
 		Example: example("secret"),
 	}
 
-	secretCmd.AddCommand(c.newSecretKeyringCmd())
+	if secretKeyringCmd := c.newSecretKeyringCmd(); secretKeyringCmd != nil {
+		secretCmd.AddCommand(secretKeyringCmd)
+	}
 
 	return secretCmd
 }
