@@ -11,7 +11,7 @@ import (
 
 const defaultEditor = "vi"
 
-var defaultInterpreters = make(map[string]*chezmoi.Interpreter)
+var defaultInterpreters = make(map[string]chezmoi.Interpreter)
 
 func fileInfoUID(info fs.FileInfo) int {
 	return int(info.Sys().(*syscall.Stat_t).Uid) //nolint:forcetypeassert
