@@ -27,13 +27,10 @@ func (c *Config) newVerifyCmd() *cobra.Command {
 		),
 	}
 
-	flags := verifyCmd.Flags()
-	flags.VarP(c.Verify.Exclude, "exclude", "x", "Exclude entry types")
-	flags.VarP(c.Verify.include, "include", "i", "Include entry types")
-	flags.BoolVar(&c.Verify.init, "init", c.Verify.init, "Recreate config file from template")
-	flags.BoolVarP(&c.Verify.recursive, "recursive", "r", c.Verify.recursive, "Recurse into subdirectories")
-
-	registerExcludeIncludeFlagCompletionFuncs(verifyCmd)
+	verifyCmd.Flags().VarP(c.Verify.Exclude, "exclude", "x", "Exclude entry types")
+	verifyCmd.Flags().VarP(c.Verify.include, "include", "i", "Include entry types")
+	verifyCmd.Flags().BoolVar(&c.Verify.init, "init", c.Verify.init, "Recreate config file from template")
+	verifyCmd.Flags().BoolVarP(&c.Verify.recursive, "recursive", "r", c.Verify.recursive, "Recurse into subdirectories")
 
 	return verifyCmd
 }
